[−][src]Enum unicode_types::miao::Miao
An enum to represent all characters in the Miao block.
Variants
LetterPa\u{16f00}: '𖼀'
LetterBa\u{16f01}: '𖼁'
LetterYiPa\u{16f02}: '𖼂'
LetterPla\u{16f03}: '𖼃'
LetterMa\u{16f04}: '𖼄'
LetterMha\u{16f05}: '𖼅'
LetterArchaicMa\u{16f06}: '𖼆'
LetterFa\u{16f07}: '𖼇'
LetterVa\u{16f08}: '𖼈'
LetterVfa\u{16f09}: '𖼉'
LetterTa\u{16f0a}: '𖼊'
LetterDa\u{16f0b}: '𖼋'
LetterYiTta\u{16f0c}: '𖼌'
LetterYiTa\u{16f0d}: '𖼍'
LetterTta\u{16f0e}: '𖼎'
LetterDda\u{16f0f}: '𖼏'
LetterNa\u{16f10}: '𖼐'
LetterNha\u{16f11}: '𖼑'
LetterYiNna\u{16f12}: '𖼒'
LetterArchaicNa\u{16f13}: '𖼓'
LetterNna\u{16f14}: '𖼔'
LetterNnha\u{16f15}: '𖼕'
LetterLa\u{16f16}: '𖼖'
LetterLya\u{16f17}: '𖼗'
LetterLha\u{16f18}: '𖼘'
LetterLhya\u{16f19}: '𖼙'
LetterTlha\u{16f1a}: '𖼚'
LetterDlha\u{16f1b}: '𖼛'
LetterTlhya\u{16f1c}: '𖼜'
LetterDlhya\u{16f1d}: '𖼝'
LetterKa\u{16f1e}: '𖼞'
LetterGa\u{16f1f}: '𖼟'
LetterYiKa\u{16f20}: '𖼠'
LetterQa\u{16f21}: '𖼡'
LetterQga\u{16f22}: '𖼢'
LetterNga\u{16f23}: '𖼣'
LetterNgha\u{16f24}: '𖼤'
LetterArchaicNga\u{16f25}: '𖼥'
LetterHa\u{16f26}: '𖼦'
LetterXa\u{16f27}: '𖼧'
LetterGha\u{16f28}: '𖼨'
LetterGhha\u{16f29}: '𖼩'
LetterTssa\u{16f2a}: '𖼪'
LetterDzza\u{16f2b}: '𖼫'
LetterNya\u{16f2c}: '𖼬'
LetterNyha\u{16f2d}: '𖼭'
LetterTsha\u{16f2e}: '𖼮'
LetterDzha\u{16f2f}: '𖼯'
LetterYiTsha\u{16f30}: '𖼰'
LetterYiDzha\u{16f31}: '𖼱'
LetterReformedTsha\u{16f32}: '𖼲'
LetterSha\u{16f33}: '𖼳'
LetterSsa\u{16f34}: '𖼴'
LetterZha\u{16f35}: '𖼵'
LetterZsha\u{16f36}: '𖼶'
LetterTsa\u{16f37}: '𖼷'
LetterDza\u{16f38}: '𖼸'
LetterYiTsa\u{16f39}: '𖼹'
LetterSa\u{16f3a}: '𖼺'
LetterZa\u{16f3b}: '𖼻'
LetterZsa\u{16f3c}: '𖼼'
LetterZza\u{16f3d}: '𖼽'
LetterZzsa\u{16f3e}: '𖼾'
LetterArchaicZza\u{16f3f}: '𖼿'
LetterZzya\u{16f40}: '𖽀'
LetterZzsya\u{16f41}: '𖽁'
LetterWa\u{16f42}: '𖽂'
LetterAh\u{16f43}: '𖽃'
LetterHha\u{16f44}: '𖽄'
LetterBri\u{16f45}: '𖽅'
LetterSyi\u{16f46}: '𖽆'
LetterDzyi\u{16f47}: '𖽇'
LetterTe\u{16f48}: '𖽈'
LetterTse\u{16f49}: '𖽉'
LetterRte\u{16f4a}: '𖽊'
SignConsonantModifierBar\u{16f4f}: '𖽏'
LetterNasalization\u{16f50}: '𖽐'
SignAspiration\u{16f51}: '𖽑'
SignReformedVoicing\u{16f52}: '𖽒'
SignReformedAspiration\u{16f53}: '𖽓'
VowelSignA\u{16f54}: '𖽔'
VowelSignAa\u{16f55}: '𖽕'
VowelSignAhh\u{16f56}: '𖽖'
VowelSignAn\u{16f57}: '𖽗'
VowelSignAng\u{16f58}: '𖽘'
VowelSignO\u{16f59}: '𖽙'
VowelSignOo\u{16f5a}: '𖽚'
VowelSignWo\u{16f5b}: '𖽛'
VowelSignW\u{16f5c}: '𖽜'
VowelSignE\u{16f5d}: '𖽝'
VowelSignEn\u{16f5e}: '𖽞'
VowelSignEng\u{16f5f}: '𖽟'
VowelSignOey\u{16f60}: '𖽠'
VowelSignI\u{16f61}: '𖽡'
VowelSignIa\u{16f62}: '𖽢'
VowelSignIan\u{16f63}: '𖽣'
VowelSignIang\u{16f64}: '𖽤'
VowelSignIo\u{16f65}: '𖽥'
VowelSignIe\u{16f66}: '𖽦'
VowelSignIi\u{16f67}: '𖽧'
VowelSignIu\u{16f68}: '𖽨'
VowelSignIng\u{16f69}: '𖽩'
VowelSignU\u{16f6a}: '𖽪'
VowelSignUa\u{16f6b}: '𖽫'
VowelSignUan\u{16f6c}: '𖽬'
VowelSignUang\u{16f6d}: '𖽭'
VowelSignUu\u{16f6e}: '𖽮'
VowelSignUei\u{16f6f}: '𖽯'
VowelSignUng\u{16f70}: '𖽰'
VowelSignY\u{16f71}: '𖽱'
VowelSignYi\u{16f72}: '𖽲'
VowelSignAe\u{16f73}: '𖽳'
VowelSignAee\u{16f74}: '𖽴'
VowelSignErr\u{16f75}: '𖽵'
VowelSignRoundedErr\u{16f76}: '𖽶'
VowelSignEr\u{16f77}: '𖽷'
VowelSignRoundedEr\u{16f78}: '𖽸'
VowelSignAi\u{16f79}: '𖽹'
VowelSignEi\u{16f7a}: '𖽺'
VowelSignAu\u{16f7b}: '𖽻'
VowelSignOu\u{16f7c}: '𖽼'
VowelSignN\u{16f7d}: '𖽽'
VowelSignNg\u{16f7e}: '𖽾'
VowelSignUog\u{16f7f}: '𖽿'
VowelSignYui\u{16f80}: '𖾀'
VowelSignOg\u{16f81}: '𖾁'
VowelSignOer\u{16f82}: '𖾂'
VowelSignVw\u{16f83}: '𖾃'
VowelSignIg\u{16f84}: '𖾄'
VowelSignEa\u{16f85}: '𖾅'
VowelSignIong\u{16f86}: '𖾆'
VowelSignUi\u{16f87}: '𖾇'
ToneRight\u{16f8f}: '𖾏'
ToneTopRight\u{16f90}: '𖾐'
ToneAbove\u{16f91}: '𖾑'
ToneBelow\u{16f92}: '𖾒'
LetterToneDash2\u{16f93}: '𖾓'
LetterToneDash3\u{16f94}: '𖾔'
LetterToneDash4\u{16f95}: '𖾕'
LetterToneDash5\u{16f96}: '𖾖'
LetterToneDash6\u{16f97}: '𖾗'
LetterToneDash7\u{16f98}: '𖾘'
LetterToneDash8\u{16f99}: '𖾙'
LetterReformedToneDash1\u{16f9a}: '𖾚'
LetterReformedToneDash2\u{16f9b}: '𖾛'
LetterReformedToneDash4\u{16f9c}: '𖾜'
LetterReformedToneDash5\u{16f9d}: '𖾝'
LetterReformedToneDash6\u{16f9e}: '𖾞'
Methods
impl Miao[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case